@@ -8,6 +8,8 @@ import importlib
 from typing import List, Tuple
 import glob
 
+from .ui import UI
+
 
 IGNORE_FILE_NAME = '.cqsignore'
 
@@ -107,8 +109,18 @@ class ModuleManager:
 
         self.load_module()
 
-        ui_class = self.get_ui_class()
-        model = ui_class.get_model()
+        ui_instance = self.get_ui_instance()
+
+        try:
+            model = ui_instance.get_model()
+        except AttributeError as error:
+            model_types = [ type(m).__name__ for m in ui_instance.models ]
+            error_message = f'The type { model_types[0] }' if len(model_types) == 1 \
+                else f"At least one of the types { ', '.join(model_types) }"
+            error_message += ' is not supported by the show function.'
+
+            ui_instance.clear()
+            raise ModuleManagerError(error_message) from error
 
         if not model:
             raise ModuleManagerError('There is no object to show. Missing show_object()?')
@@ -117,23 +129,41 @@ class ModuleManager:
 
     def load_module(self) -> None:
         '''Load or reload the `self.module_name` module.'''
+        # pylint: disable=broad-except
 
         if self.module_name not in self.get_modules_name():
             raise ModuleManagerError(f'Module "{ self.module_name }" is not available '
                 + 'in the current context.')
 
-        try:
-            if self.module_name in sys.modules:
-                print(f'Reloading module { self.module_name }...')
-                importlib.reload(self.modules[self.module_name])
-            else:
-                print(f'Importing module { self.module_name }...')
-                self.modules[self.module_name] = importlib.import_module(self.module_name)
+        error = None
+        if self.module_name in self.modules:
+            print(f'Reloading module { self.module_name }...')
 
-        except Exception as error:
-            error_message = type(error).__name__ + ': ' + str(error)
+            try:
+                importlib.reload(self.modules[self.module_name])
+            except Exception:
+                print('Error when reloading module, trying to re-import it...')
+
+                try:
+                    self.modules[self.module_name] = importlib.import_module(self.module_name)
+                    importlib.reload(self.modules[self.module_name])
+                except Exception as err:
+                    error = err
+
+        else:
+            print(f'Importing module { self.module_name }...')
+
+            try:
+                self.modules[self.module_name] = importlib.import_module(self.module_name)
+            except Exception as err:
+                error = err
+
+        if error:
+            error_message = 'Can not load module. ' + type(error).__name__ + ': ' + str(error)
             raise ModuleManagerError(error_message, traceback.format_exc()) from error
 
+        print('Done.')
+
     def get_data(self) -> dict:
         '''Return the data to send to the client, that includes the tesselated model.'''
 
@@ -146,7 +176,8 @@ class ModuleManager:
                     'model': self.get_model()
                 }
             except ModuleManagerError as error:
-                data={
+                # self.modules.pop(self.module_name)
+                data = {
                     'error': error.message,
                     'stacktrace': error.stacktrace
                 }
@@ -158,14 +189,14 @@ class ModuleManager:
 
         return [ op.basename(path)[:-3] for path in self.get_modules_path() ]
 
-    def get_ui_class(self) -> type:
-        '''Retrieve the UI class imported in the user CadQuery script, used to get the model.'''
+    def get_ui_instance(self) -> UI:
+        '''Retrieve the ui object imported in the CadQuery script, used to retrieve the model.'''
 
         try:
-            return getattr(self.modules[self.module_name], 'UI')
+            return getattr(self.modules[self.module_name], 'ui')
         except AttributeError as error:
-            raise ModuleManagerError('UI class is not imported. '
-                + 'Please add `from cq_server.ui import UI, show_object` '
+            raise ModuleManagerError('ui is not imported. '
+                + 'Please add `from cq_server.ui import ui, show_object` '
                 + 'at the begining of the script.') from error
 
 
