@@ -7,9 +7,9 @@ from time import sleep
 import os.path as op
 from typing import Tuple
 
-from flask import Flask, request, render_template, Response
+from flask import Flask, request, render_template, make_response, Response
 
-from .module_manager import ModuleManager, ModuleManagerError
+from .module_manager import ModuleManager
 from .renderers import get_static_html
 
 
@@ -47,26 +47,22 @@ def run(port: int, module_manager: ModuleManager, ui_options: dict, is_dead: boo
         if module_manager.target_is_dir:
             module_manager.module_name = request.args.get('m')
 
-        try:
-            model = module_manager.get_model()
-        except ModuleManagerError as error:
-            return {
-                'error': error.message,
-                'stacktrace': error.stacktrace
-            }, 400
-
-        return {
-            'module_name': module_manager.module_name,
-            'model': model
-        }, 200
+        data = module_manager.get_data()
+        return data, (400 if 'error' in data else 200)
 
     @app.route('/events', methods = [ 'GET' ])
     def _events() -> Response:
         def stream():
             while True:
-                yield events_queue.get()
+                data = events_queue.get()
+                print(f'Sending Server Sent Event: { data[:100] }...')
+                yield data
 
-        return Response(stream(), mimetype='text/event-stream')
+        response = make_response(stream())
+        response.mimetype = 'text/event-stream'
+        response.headers['Cache-Control'] = 'no-store, must-revalidate'
+        response.headers['Expires'] = 0
+        return response
 
     def watchdog() -> None:
         while True:
@@ -74,10 +70,7 @@ def run(port: int, module_manager: ModuleManager, ui_options: dict, is_dead: boo
 
             if last_updated_file:
                 module_manager.module_name = op.basename(last_updated_file)[:-3]
-                data = {
-                    'module_name': module_manager.module_name,
-                    'model': module_manager.get_model()
-                }
+                data = module_manager.get_data()
                 events_queue.put(SSE_MESSAGE_TEMPLATE % json.dumps(data))
             sleep(WATCH_PERIOD)
 
